@@ -5,4 +5,7 @@ def brian():
     print("Hei Brian")
 
 def mango():
-    print("Mangooooooo")
\ No newline at end of file
+    print("Mangooooooo")
+    
+def mango2():
+    print("Mer mangoooo")
\ No newline at end of file
